# pytket-projectq

[Pytket](https://cqcl.github.io/pytket) is a Python module for interfacing
with CQC tket, a set of quantum programming tools.

[ProjectQ](https://github.com/ProjectQ-Framework/ProjectQ) is an open-source
library for quantum circuit compilation and simulation.

`pytket-projectq` is an extension to `pytket` that allows `pytket` circuits to
be run on ProjectQ simulators, as well as conversion to the ProjectQ
representation.

## Getting started

`pytket-projectq` is available for Python 3.7, 3.8 and 3.9, on Linux, MacOS and Windows.
To install, run:

```pip install pytket-projectq```
